Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetHostLifetimeContext ¶
Returns the host lifetime context stored in the passed context. This is useful for goroutines serve long-running operations that survive the lifetime of the request.
Types ¶
type DcpContextValueKey ¶
type DcpContextValueKey string
const ( HostLifetimeContextKey DcpContextValueKey = "HostLifetimeContext" LoggerContextKey DcpContextValueKey = "LoggerContext" ProcessExecutorContextKey DcpContextValueKey = "ProcessExecutor" )
Click to show internal directories.
Click to hide internal directories.