dcpclient

package
v0.22.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 26, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

const (
	DefaultServerConnectTimeout = 15 * time.Second
)

Variables

This section is empty.

Functions

func ApplyDcpOptions

func ApplyDcpOptions(config *clientgorest.Config)

func NewClient

func NewClient(ctx context.Context, timeout time.Duration) (ctrl_client.Client, error)

NewClient() returns new client for the DCP API server.

The standard controller runtime client factory function does dynamic discovery at startup. If the API server is not already running, it will fail with error immediately. NewClient() will re-try client creation, with exponential back-off, until the time out is reached.

func NewClientFromConfig

func NewClientFromConfig(timeoutCtx context.Context, config *clientgorest.Config) (ctrl_client.Client, error)

NewClientFromConfig() returns new client for the DCP API server, using the provided configuration object. The standard controller runtime client factory function does dynamic discovery at startup. If the API server is not already running, it will fail with error immediately. NewClientFromConfig() will re-try client creation, with exponential back-off, until the time out is reached.

func NewConfigFromKubeconfigFile

func NewConfigFromKubeconfigFile(timeoutCtx context.Context, kubeconfigPath string) (*clientgorest.Config, error)

Creates a new Kubernetes client configuration from a kubeconfig file.

func NewScheme

func NewScheme() *apiruntime.Scheme

Types

This section is empty.

Jump to