dcppaths

package
v0.22.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 3, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

const (
	DcpUserDir           = ".dcp"
	DcpExtensionsDir     = "ext"
	DcpBinDir            = "bin"
	DcpWorkDir           = "dcp-work"
	DcpExtensionsPathEnv = "DCP_EXTENSIONS_PATH"
	DcpBinPathEnv        = "DCP_BIN_PATH"
)

Variables

This section is empty.

Functions

func EnableTestPathProbing

func EnableTestPathProbing()

Used by tests only, enables probing for additional DCP paths during test runs.

func EnsureUserDcpDir

func EnsureUserDcpDir() (string, error)

Returns the full path to user DCP data directory, attempting to create it as necessary.

func GetDcpBinDir

func GetDcpBinDir() (string, error)

func GetDcpExePath added in v0.22.3

func GetDcpExePath() (string, error)

func GetExtensionsDirs

func GetExtensionsDirs() ([]string, error)

func WithDcpBinDir

func WithDcpBinDir(cmd *exec.Cmd)

Types

This section is empty.

Jump to