proto

package
v0.22.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 23, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type TunnelRequestFingerprint

type TunnelRequestFingerprint struct {
	ServerAddress      string
	ServerPort         int32
	ClientProxyAddress string
	ClientProxyPort    int32
}

TunnelRequestFingerprint is a set of fields that uniquely identify a tunnel request. It is used to determine if two tunnel requests are effectively the same, and to de-duplicate tunnel requests.

func (TunnelRequestFingerprint) String

func (f TunnelRequestFingerprint) String() string

Jump to