exerunners

package
v0.22.11 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: MIT Imports: 39 Imported by: 0

Documentation

Index

Constants

const (
	DCP_IDE_REQUEST_TIMEOUT_SECONDS        = "DCP_IDE_REQUEST_TIMEOUT_SECONDS"
	DCP_IDE_NOTIFICATION_TIMEOUT_SECONDS   = "DCP_IDE_NOTIFICATION_TIMEOUT_SECONDS"
	DCP_IDE_NOTIFICATION_KEEPALIVE_SECONDS = "DCP_IDE_NOTIFICATION_KEEPALIVE_SECONDS"
)
const (

	// Two things need to happen before the run change handler is called:
	// 1. The StartRun() method of the IDE runner must get a chance to set the change handler.
	// 2. The IDE runner consumer must call startWaitForRunCompletion() for the run.
	RequiredChangeHandlerReadiness = 2
)

Variables

This section is empty.

Functions

func NewIdeConnectionInfo

func NewIdeConnectionInfo(lifetimeCtx context.Context, log logr.Logger) (*ideConnectionInfo, error)

func NewIdeNotificationHandler

func NewIdeNotificationHandler(
	lifetimeCtx context.Context,
	notificationReceiver ideNotificationRecevier,
	connInfo *ideConnectionInfo,
	log logr.Logger,
) *ideNotificationHandler

func NewRunData

func NewRunData(lifetimeCtx context.Context) *runData

func NewStartingState

func NewStartingState(status apiv1.ExecutableStatus) *startingState

Types

type IdeExecutableRunner

type IdeExecutableRunner struct {
	// contains filtered or unexported fields
}

func NewIdeExecutableRunner

func NewIdeExecutableRunner(lifetimeCtx context.Context, log logr.Logger) (*IdeExecutableRunner, error)

func (*IdeExecutableRunner) HandleServiceLogs

func (r *IdeExecutableRunner) HandleServiceLogs(nsl ideSessionLogNotification)

func (*IdeExecutableRunner) HandleSessionChange

func (r *IdeExecutableRunner) HandleSessionChange(pcn ideRunSessionProcessChangedNotification)

func (*IdeExecutableRunner) HandleSessionMessage

func (r *IdeExecutableRunner) HandleSessionMessage(smn ideSessionMessageNotification)

func (*IdeExecutableRunner) HandleSessionTermination

func (r *IdeExecutableRunner) HandleSessionTermination(stn ideRunSessionTerminatedNotification)

func (*IdeExecutableRunner) StartRun

func (*IdeExecutableRunner) StopRun

func (r *IdeExecutableRunner) StopRun(ctx context.Context, runID controllers.RunID, log logr.Logger) error

type ProcessExecutableRunner

type ProcessExecutableRunner struct {
	// contains filtered or unexported fields
}

func NewProcessExecutableRunner

func NewProcessExecutableRunner(pe process.Executor) *ProcessExecutableRunner

func (*ProcessExecutableRunner) StartRun

func (*ProcessExecutableRunner) StopRun

Jump to