Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WriteCapabiltiesDoc ¶
Types ¶
type CanRenderResponse ¶
type CanRenderResponse struct {
Result CanRenderResult `json:"result"`
Reason string `json:"reason,omitempty"` // Must be provided if result is "no".
}
func (CanRenderResponse) IsValid ¶
func (c CanRenderResponse) IsValid() error
type CanRenderResult ¶
type CanRenderResult string
Keep in sync with https://github.com/microsoft/dcp/schemas/v1.0/can-render.json
const ( CanRenderResultYes CanRenderResult = "yes" CanRenderResultNo CanRenderResult = "no" )
type ExtensionCapabilities ¶
type ExtensionCapabilities struct {
Name string `json:"name"` // Name of the extension, for error reporting and similar purposes.
Id string `json:"id"` // Unique ID of the extension, primarily for referring to the extension via command-line arguments.
Capabilities []ExtensionCapability `json:"capabilities"`
}
type ExtensionCapability ¶
type ExtensionCapability string
Keep in sync with https://github.com/microsoft/dcp/schemas/v1.0/capabilities.json
const ( // The extension is a controller host. ControllerCapability ExtensionCapability = "controller" // The extension is a workload renderer. WorkloadRendererCapability ExtensionCapability = "workload-renderer" // The extension is the API server (there can be only one). ApiServerCapability ExtensionCapability = "api-server" // The extension accepts --monitor flag for parent process monitoring. // This implies it should not be terminated when DCP is shutting down; it will exit on its own when DCP process exist. // This allows it to perform a graceful shutdown. ProcessMonitorCapability ExtensionCapability = "process-monitor" )
Click to show internal directories.
Click to hide internal directories.