contextdata

package
v0.22.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 6, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetContextLogger

func GetContextLogger(ctx context.Context) logr.Logger

func GetHostLifetimeContext

func GetHostLifetimeContext(ctx context.Context) context.Context

Returns the host lifetime context stored in the passed context. This is useful for goroutines serve long-running operations that survive the lifetime of the request.

func GetProcessExecutor

func GetProcessExecutor(ctx context.Context) process.Executor

Types

type DcpContextValueKey

type DcpContextValueKey string
const (
	HostLifetimeContextKey    DcpContextValueKey = "HostLifetimeContext"
	LoggerContextKey          DcpContextValueKey = "LoggerContext"
	ProcessExecutorContextKey DcpContextValueKey = "ProcessExecutor"
)

Jump to