Documentation
¶
Index ¶
- Constants
- func ApplyDcpOptions(config *clientgorest.Config)
- func NewClient(ctx context.Context, timeout time.Duration) (ctrl_client.Client, error)
- func NewClientFromConfig(timeoutCtx context.Context, config *clientgorest.Config) (ctrl_client.Client, error)
- func NewConfigFromKubeconfigFile(timeoutCtx context.Context, kubeconfigPath string) (*clientgorest.Config, error)
- func NewScheme() *apiruntime.Scheme
Constants ¶
const (
DefaultServerConnectTimeout = 15 * time.Second
)
Variables ¶
This section is empty.
Functions ¶
func ApplyDcpOptions ¶
func ApplyDcpOptions(config *clientgorest.Config)
func NewClient ¶
NewClient() returns new client for the DCP API server.
The standard controller runtime client factory function does dynamic discovery at startup. If the API server is not already running, it will fail with error immediately. NewClient() will re-try client creation, with exponential back-off, until the time out is reached.
func NewClientFromConfig ¶
func NewClientFromConfig(timeoutCtx context.Context, config *clientgorest.Config) (ctrl_client.Client, error)
NewClientFromConfig() returns new client for the DCP API server, using the provided configuration object. The standard controller runtime client factory function does dynamic discovery at startup. If the API server is not already running, it will fail with error immediately. NewClientFromConfig() will re-try client creation, with exponential back-off, until the time out is reached.
func NewConfigFromKubeconfigFile ¶
func NewConfigFromKubeconfigFile(timeoutCtx context.Context, kubeconfigPath string) (*clientgorest.Config, error)
Creates a new Kubernetes client configuration from a kubeconfig file.
func NewScheme ¶
func NewScheme() *apiruntime.Scheme
Types ¶
This section is empty.