Documentation
¶
Index ¶
Constants ¶
const ( DcpUserDir = ".dcp" DcpExtensionsDir = "ext" DcpBinDir = "bin" DcpWorkDir = "dcp-work" DcpExtensionsPathEnv = "DCP_EXTENSIONS_PATH" DcpBinPathEnv = "DCP_BIN_PATH" )
Variables ¶
This section is empty.
Functions ¶
func EnableTestPathProbing ¶
func EnableTestPathProbing()
Used by tests only, enables probing for additional DCP paths during test runs.
func EnsureUserDcpDir ¶
Returns the full path to user DCP data directory, attempting to create it as necessary.
func GetDcpBinDir ¶
func GetDcpExePath ¶ added in v0.22.3
func GetExtensionsDirs ¶
func WithDcpBinDir ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.