Documentation
¶
Index ¶
- Constants
- func RunContainerWatcher(pe process.Executor, containerID string, log logr.Logger)
- func RunProcessWatcher(pe process.Executor, childPid process.Pid_t, childStartTime time.Time, ...)
- func SimulateStopProcessTreeCommand(pe *internal_testutil.ProcessExecution) int32
- func StopProcessTree(ctx context.Context, pe process.Executor, rootPid process.Pid_t, ...) error
Constants ¶
const (
DCP_DISABLE_MONITOR_PROCESS = "DCP_DISABLE_MONITOR_PROCESS"
)
Variables ¶
This section is empty.
Functions ¶
func RunContainerWatcher ¶
Starts the container monitor for the given container ID, using current process as the "monitored", or watched, process. The caller should ensure that the current process is the correct process to monitor. Errors are logged, but no error is returned if the container monitor fails to start-- container monitor is considered a "best-effort reliability enhancement".
func RunProcessWatcher ¶
func RunProcessWatcher( pe process.Executor, childPid process.Pid_t, childStartTime time.Time, log logr.Logger, )
Starts the process monitor for the given child process, using current process as the "monitored", or watched, process. The caller should ensure that the current process is the correct process to monitor. Errors are logged, but no error is returned if the process monitor fails to start-- process monitor is considered a "best-effort reliability enhancement". Note: DCP process doesn't shut down if DCPCTRL goes away, but DCPCTRL will shut down if DCP process goes away, so monitoring DCPCTRL is a safe bet.
func SimulateStopProcessTreeCommand ¶
func SimulateStopProcessTreeCommand(pe *internal_testutil.ProcessExecution) int32
Types ¶
This section is empty.