Documentation
¶
Index ¶
- Constants
- func NewIdeConnectionInfo(lifetimeCtx context.Context, log logr.Logger) (*ideConnectionInfo, error)
- func NewIdeNotificationHandler(lifetimeCtx context.Context, notificationReceiver ideNotificationRecevier, ...) *ideNotificationHandler
- func NewRunData(lifetimeCtx context.Context) *runData
- func NewStartingState(status apiv1.ExecutableStatus) *startingState
- type IdeExecutableRunner
- func (r *IdeExecutableRunner) HandleServiceLogs(nsl ideSessionLogNotification)
- func (r *IdeExecutableRunner) HandleSessionChange(pcn ideRunSessionProcessChangedNotification)
- func (r *IdeExecutableRunner) HandleSessionMessage(smn ideSessionMessageNotification)
- func (r *IdeExecutableRunner) HandleSessionTermination(stn ideRunSessionTerminatedNotification)
- func (r *IdeExecutableRunner) StartRun(ctx context.Context, exe *apiv1.Executable, ...) *controllers.ExecutableStartResult
- func (r *IdeExecutableRunner) StopRun(ctx context.Context, runID controllers.RunID, log logr.Logger) error
- type ProcessExecutableRunner
Constants ¶
const ( DCP_IDE_REQUEST_TIMEOUT_SECONDS = "DCP_IDE_REQUEST_TIMEOUT_SECONDS" DCP_IDE_NOTIFICATION_TIMEOUT_SECONDS = "DCP_IDE_NOTIFICATION_TIMEOUT_SECONDS" DCP_IDE_NOTIFICATION_KEEPALIVE_SECONDS = "DCP_IDE_NOTIFICATION_KEEPALIVE_SECONDS" )
const ( // Two things need to happen before the run change handler is called: // 1. The StartRun() method of the IDE runner must get a chance to set the change handler. // 2. The IDE runner consumer must call startWaitForRunCompletion() for the run. RequiredChangeHandlerReadiness = 2 )
Variables ¶
This section is empty.
Functions ¶
func NewIdeConnectionInfo ¶
func NewRunData ¶
func NewStartingState ¶
func NewStartingState(status apiv1.ExecutableStatus) *startingState
Types ¶
type IdeExecutableRunner ¶
type IdeExecutableRunner struct {
// contains filtered or unexported fields
}
func NewIdeExecutableRunner ¶
func (*IdeExecutableRunner) HandleServiceLogs ¶
func (r *IdeExecutableRunner) HandleServiceLogs(nsl ideSessionLogNotification)
func (*IdeExecutableRunner) HandleSessionChange ¶
func (r *IdeExecutableRunner) HandleSessionChange(pcn ideRunSessionProcessChangedNotification)
func (*IdeExecutableRunner) HandleSessionMessage ¶
func (r *IdeExecutableRunner) HandleSessionMessage(smn ideSessionMessageNotification)
func (*IdeExecutableRunner) HandleSessionTermination ¶
func (r *IdeExecutableRunner) HandleSessionTermination(stn ideRunSessionTerminatedNotification)
func (*IdeExecutableRunner) StartRun ¶
func (r *IdeExecutableRunner) StartRun( ctx context.Context, exe *apiv1.Executable, runChangeHandler controllers.RunChangeHandler, log logr.Logger, ) *controllers.ExecutableStartResult
func (*IdeExecutableRunner) StopRun ¶
func (r *IdeExecutableRunner) StopRun(ctx context.Context, runID controllers.RunID, log logr.Logger) error
type ProcessExecutableRunner ¶
type ProcessExecutableRunner struct {
// contains filtered or unexported fields
}
func NewProcessExecutableRunner ¶
func NewProcessExecutableRunner(pe process.Executor) *ProcessExecutableRunner
func (*ProcessExecutableRunner) StartRun ¶
func (r *ProcessExecutableRunner) StartRun( ctx context.Context, exe *apiv1.Executable, runChangeHandler controllers.RunChangeHandler, log logr.Logger, ) *controllers.ExecutableStartResult
func (*ProcessExecutableRunner) StopRun ¶
func (r *ProcessExecutableRunner) StopRun(ctx context.Context, runID controllers.RunID, log logr.Logger) error
Click to show internal directories.
Click to hide internal directories.