grpcutil

package
v0.23.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 30, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func EnumVal

func EnumVal[T ~int32](v T) *T

Make a pointer from an enum value, for the purpose of creating protobuf messages. Compare with the wrappers in the google.golang.org/protobuf/proto package.

func IsStreamDoneErr

func IsStreamDoneErr(err error) bool

Returns true if the error is one of the errors that can happen if a gRPC stream is ended by the client, or the associated context is cancelled during send/receive operation.

func StreamRetryBackoff

func StreamRetryBackoff() *backoff.ExponentialBackOff

Returns exponential backoff policy suitable for retrying send/receive operations on gRPC streams.

Types

This section is empty.

Jump to