Documentation
¶
Index ¶
Constants ¶
const ( MaxLineLength = 128 TicksPerMs int64 = 10_000 TicksPerSec = 1_000 * TicksPerMs )
Variables ¶
This section is empty.
Functions ¶
func FormatLine ¶
FormatLine creates a line with the same format as the C# implementation
func WriteLinesAsync ¶
func WriteLinesAsync(w io.Writer, opts *WriteOptions, done <-chan struct{})
WriteLinesAsync writes lines to the given stream based on the provided options
Types ¶
type WriteOptions ¶
type WriteOptions struct {
Delay time.Duration
Logger *logr.Logger
MaxRows int64
RowsPerDelay int64
RowsPerLog int64
}
WriteOptions configures how lines are written to the stream
func NewLocalWriteOptions ¶
func NewLocalWriteOptions(logger *logr.Logger) *WriteOptions
NewLocalWriteOptions creates write options for local streaming
func NewWebWriteOptions ¶
func NewWebWriteOptions(logger *logr.Logger) *WriteOptions
NewWebWriteOptions creates write options for web streaming
Click to show internal directories.
Click to hide internal directories.