Documentation
¶
Index ¶
Constants ¶
const (
NoSeparateWorkingDir = ""
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AdvancedTestEnvironmentInfo ¶ added in v0.22.2
type AdvancedTestEnvironmentInfo struct {
ProcessExecutor process.Executor
*ctrl_testutil.TestProcessExecutableRunner
}
AdvancedTestEnvironmentInfo provides information about the test environment created via StartAdvancedTestEnvironment().
func StartAdvancedTestEnvironment ¶
func StartAdvancedTestEnvironment( ctx context.Context, inclCtrl IncludedController, instanceTag string, testTempDir string, log logr.Logger, ) ( *ctrl_testutil.ApiServerInfo, *AdvancedTestEnvironmentInfo, error, )
Starts an test environment for advanced tests that use real process executor and true container orchestrator (Docker or Podman). Note that the Executable controller (if included in the mix) only supports process execution (no IDE execution).
type IncludedController ¶
type IncludedController uint32
const ( ExecutableController IncludedController = 1 << iota ExecutableReplicaSetController NetworkController ContainerController ContainerExecController VolumeController ServiceController ContainerNetworkTunnelProxyController NoControllers IncludedController = 0 AllControllers IncludedController = ^NoControllers )
type TestEnvironmentInfo ¶
type TestEnvironmentInfo struct {
*internal_testutil.TestProcessExecutor
*ctrl_testutil.TestProcessExecutableRunner
*ctrl_testutil.TestIdeRunner
*ctrl_testutil.TestTunnelControlClient
}
TestEnvironmentInfo provides information about the test environment created via StartTestEnvironment().
func StartTestEnvironment ¶
func StartTestEnvironment( ctx context.Context, inclCtrl IncludedController, instanceTag string, testTempDir string, log logr.Logger, ) ( *ctrl_testutil.ApiServerInfo, *TestEnvironmentInfo, error, )
Starts the DCP API server (separate process) and standard controllers (in-proc).
Click to show internal directories.
Click to hide internal directories.